pub struct N3Quad {
pub subject: N3Term,
pub predicate: N3Term,
pub object: N3Term,
pub graph_name: GraphName,
}Expand description
A N3 quad i.e. a quad composed of N3Term.
The graph_name is used to encode the formula where the triple is in.
In this case the formula is encoded by a blank node.
Fields
subject: N3TermThe subject of this triple.
predicate: N3TermThe predicate of this triple.
object: N3TermThe object of this triple.
graph_name: GraphNameThe name of the RDF graph in which the triple is.